@@ -124,7 +124,10 @@ def parser_people_links(link):
                 if sou.get('href').find(".ru") == -1:
                     links.append({"link":link[:-1] + sou.get('href'), "name": sou.get_text()})
                 else:
-                    links.append({"link":sou.get('href'), "name": sou.get_text()})
+                    if sou.get('href').find("http") == -1:
+                        links.append({"link": "http:/" + sou.get('href'), "name": sou.get_text()})
+                    else:
+                        links.append({"link": sou.get('href'), "name": sou.get_text()})
     else:
         links = None
     return links
@@ -173,10 +176,42 @@ def get_orenburg():
         people.append(parser_person(link, 'https://orenburg.arbitr.ru/'))
     return people
 
+def parser_irk(link):
+    people = []
+    html_irk_1 = f.get_html(link)
+    soup_irk_1 = BeautifulSoup(html_irk_1.text, "html.parser")
+    soup_irk_1 = soup_irk_1.find("div", class_="single")
+    soup_irk_1 = soup_irk_1.find_all("a")
+    for syd in soup_irk_1:
+        html_syd = f.get_html(syd.get("href"))
+        soup_irk_syd = BeautifulSoup(html_syd.text, "html.parser")
+        soup_irk_syd = soup_irk_syd.find("div", class_="single")
+        soup_irk_syd = soup_irk_syd.find_all("a")
+        for sou in soup_irk_syd:
+            name = sou.get_text()
+            name = name.split()
+            work = 44
+            if len(name) > 3:
+                work = 42
+                name = name[4:]
+            people.append({
+                'image_link': "-",
+                'first_name': name[1],
+                'middle_name': name[2],
+                'last_name': name[0],
+                'link': sou.get("href"),
+                'bday': 1,
+                'bmonth': 1,
+                'byear': 1901,
+                'position_id': work,
+            })
+    return people
+
 def parser():
     log.debug(f"The script {__name__} starts working")
     links = []
     people = []
+
     html = f.get_html(url)
     if html.status_code == 200:
         soup = BeautifulSoup(html.text, 'html.parser')
@@ -221,6 +256,90 @@ def parser():
                 if person != 1:
                     people.append(person)
         people.extend(get_orenburg())
+
+        html_tver = f.get_html("https://tver.arbitr.ru/node/3515")
+        soup_tver = BeautifulSoup(html_tver.text, "html.parser")
+        soup_tver = soup_tver.find("div", class_="node")
+        tver_list = soup_tver.find_all("p")
+        tver_list = tver_list[1:]
+        for item in tver_list:
+            name = item.find("strong").get_text().replace("\n", "")
+            name = f.get_name(name)
+            people.append({
+                'image_link': "-",
+                'first_name': name[1],
+                'middle_name': name[2],
+                'last_name': name[0],
+                'link': "https://tver.arbitr.ru/node/3515",
+                'bday': 1,
+                'bmonth': 1,
+                'byear': 1901,
+                'position_id': 44,
+            })
+
+        html_fasvso = f.get_html("http://fasvso.arbitr.ru/about/struktura_suda/svedeniya_o_sud_yah/")
+        soup_fasvso = BeautifulSoup(html_fasvso.text, "html.parser")
+        soup_fasvso = soup_fasvso.find('div', class_="evaldyarticles")
+        soup_fasvso = soup_fasvso.find_all("div")
+        for item in soup_fasvso:
+            li = "http://fasvso.arbitr.ru" + item.find("a").get("href")
+            name = item.get_text().lower().replace("\n", "")
+            name = f.get_name(name)
+            people.append({
+                'image_link': "-",
+                'first_name': name[1],
+                'middle_name': name[2],
+                'last_name': name[0],
+                'link': li,
+                'bday': 1,
+                'bmonth': 1,
+                'byear': 1901,
+                'position_id': 44,
+            })
+
+        html_irk = f.get_html(
+            "https://irkutsk.arbitr.ru/o-sude/struktura-suda/sudi/predsedatel-arbitrazhnogo-suda-irkutskoj-oblasti/")
+        soup_irk = BeautifulSoup(html_irk.text, "html.parser")
+        soup_irk = soup_irk.find("div", class_="single")
+        im = soup_irk.find("strong")
+        name = im.get_text()
+        name = f.get_name(name)
+        soup_irk = soup_irk.find_all("p")
+        date = soup_irk[2].get_text().lower()
+        if date.find('родился') != -1:
+            year = date.find('года')
+            if year != -1:
+                date = date[date.find('родился') + len('родился'):year]
+            elif date.find('г.') != -1:
+                date = date[date.find('родился') + len('родился'):date.find('г.')]
+        elif date.find('родилась') != -1:
+            year = date.find('года')
+            if year != -1:
+                date = date[date.find('родилась') + len('родилась'):year]
+            elif date.find('г.') != -1:
+                date = date[date.find('родилась') + len('родилась'):date.find('г.')]
+        else:
+            date = date[date.find('.') - 2:date.find('.') + 8]
+        date = date.replace('.', ' ')
+        date = f.get_dig_date(date)
+
+        people.append({
+            'image_link': im.find("a").get("href"),
+            'first_name': name[0],
+            'middle_name': name[1],
+            'last_name': name[2],
+            'link': "https://irkutsk.arbitr.ru/o-sude/struktura-suda/sudi/predsedatel-arbitrazhnogo-suda-irkutskoj-oblasti",
+            'bday': date["day"],
+            'bmonth': date["month"],
+            'byear': date["year"],
+            'position_id': 42,
+        })
+
+        people.extend(parser_irk(
+            "https://irkutsk.arbitr.ru/o-sude/struktura-suda/sudi/sudebnaya-kollegiya-po-rassmotreniyu-sporov-voznikayushhih-iz-administrativnyh-i-inyh-publichnyh-pravootnoshenij/"))
+        people.extend(parser_irk(
+            "https://irkutsk.arbitr.ru/o-sude/struktura-suda/sudi/sudebnaya-kollegiya-po-rassmotreniyu-sporov-voznikayushhih-iz-grazhdanskih-i-inyh-pravootnoshenij/"))
+
         log.debug("The script stops working")
         return people
     else:
